//===========================================================================
// spiral.cpp
// 2D-Linien zeichnen mit OpenGL
//===========================================================================

//===========================================================================
// includes
//===========================================================================

#include "spiral.h"

/* OpenGL Bibliothek einbinden (je nach Betriebssystem) */

#ifdef WIN32
    #include <windows.h>
    #include <GL/gl.h>
#else
    #include <GL/gl.h>
#endif

// Mathematikbibliothek einbinden (Sinus und Cosinus)

#include <math.h>


//===========================================================================
// Konstanten
//===========================================================================

// Die Kreiszahl PI
const float PI = asin(1.0f) * 2.0f;


//===========================================================================
// Klassenimplementierung
//===========================================================================

CSpiral::CSpiral()
{
    // initialisiere Variablen
    m_radius   = 2.0f;
    m_steps    = 2000;
    m_rotation = 0.0f;
}


CSpiral::~CSpiral()
{
    // nichts aufzurumen
}


void CSpiral::rotate(float degrees)
{
    // Rotation weiter rotieren
    m_rotation += degrees;
}


void CSpiral::render()
{
    // Bisherige Geometrie-Transofmrationen auf Stapel sichern
    glMatrixMode(GL_MODELVIEW);
    glPushMatrix();

    // Gesamte Geometrie um positive z-Achse rotieren
    glRotatef(m_rotation, 0.0f, 0.0f, 1.0f);

    // Linienbreite auf 5 Pixel setzen
    glLineWidth(5);

    // Linienzug beginnen
    glBegin(GL_LINE_STRIP);

    for (unsigned int i = 0; i < m_steps; i++)
    {
        // Wert von i zwischen 0 und 1 skalieren
        float fader = float(i) / float(m_steps-1);

        // Winkel und Radius berechnen
        float angle  = fader*60.0f*PI;
        float radius = fader*m_radius;

        // (x,y) Koordinate bestimmen (Kreis mit wachsendem Radius)
        float x = cosf(angle) * radius;
        float y = sinf(angle) * radius;
        
        // Vektor, durch den die Linie gezogen werden soll, setzen
        glVertex2f(x, y);
    }

    // Ende des Linienzuges
    glEnd();

    // Geometrie-Rotation aufheben
    // (alte Transformationen vom Stapel holen)
    glPopMatrix();

} // render()
